@@ -1,11 +1,37 @@
 graphHab <- function(res, file = "", dim = 1:2, hab = NULL, ellipse = TRUE, Iselec = "contrib", Rselec = "cos2", Cselec = "contrib", Icoef = 1, Rcoef = 1, Ccoef = 1, figure.title = "Figure", graph = TRUE, cex = 0.7, options=NULL) {
 
+# test.de.Wilks <- function(x,grouping){
+  # if (any(summary(grouping)<2)){
+    # notok=grouping%in%(levels(grouping)[which(summary(grouping)<2)])
+    # aux <- rrcov::Wilks.test(x[!notok,,drop=FALSE],grouping[!notok])$parameter
+  # } else aux <- rrcov::Wilks.test(x,grouping)$parameter
+  # pchisq(aux[1],aux[2],lower.tail=FALSE)
+# }
+
 test.de.Wilks <- function(x,grouping){
+
+  if(is.data.frame(x)) x <- data.matrix(x)
+
   if (any(summary(grouping)<2)){
     notok=grouping%in%(levels(grouping)[which(summary(grouping)<2)])
-    aux <- rrcov::Wilks.test(x[!notok,,drop=FALSE],grouping[!notok])$parameter
-  } else aux <- rrcov::Wilks.test(x,grouping)$parameter
-  pchisq(aux[1],aux[2],lower.tail=FALSE)
+    x <- x[!notok,,drop=FALSE]
+	grouping <- as.factor(as.character(grouping[!notok]))
+}
+
+    lev <- levels(grouping)
+    ng <- length(lev)
+    wts <- rep(1, nrow(x))
+    group.means <- matrix(0,ng,ncol(x))
+    for(i in 1:ng) group.means[i,] <- stats::cov.wt(x[which(grouping == lev[i]),], wt=wts[which(grouping == lev[i])])$center
+
+    wcross <- stats::cov.wt((x - group.means[grouping, ]), wt=wts)
+    wcross <- (sum(wts)-1) * wcross$cov
+    tcross <- stats::cov.wt(x, wt=wts)
+    tcross <- (sum(wts)-1) * tcross$cov
+
+    wilks <- det(wcross)/det(tcross)
+    p.value <- pchisq(-(nrow(x) - 1 - (ncol(x)+ng)/2)*log(wilks), ncol(x)*(ng-1), lower.tail=FALSE)
+	return(p.value)
 }
 
     if(!is.character(file)) {return(warning("the parameter 'file' has to be a character chain giving the name of the .Rmd file to write in"))}
@@ -116,7 +142,7 @@ test.de.Wilks <- function(x,grouping){
                
                #shuffle
                res$ind$coord = res$ind$coord[sample[!sample %in% rownames(res$ind.sup$coord)],]
-               res$ind.sup$coord = res$ind.sup$coord[sample[sample %in% rownames(res$ind.sup$coord)],] # works even if ind.sup = NULL
+               res$ind.sup$coord = res$ind.sup$coord[sample[sample %in% rownames(res$ind.sup$coord)],,drop=FALSE] # works even if ind.sup = NULL
                
                if(ellipse) {
                  plotellipses(res, axes = dim[1]:dim[2], invisible = 'quali', select = drawn, keepvar = hab, title = gettext("Individuals factor map (PCA)",domain="R-FactoInvestigate"), cex = cex)
@@ -129,7 +155,7 @@ test.de.Wilks <- function(x,grouping){
              writeRmd("sample = sample(rownames(res$call$X), length(rownames(res$call$X)))", file = file, start = TRUE, options = options)
              writeRmd("res$call$X = res$call$X[sample,]", file = file)
              writeRmd("res$ind$coord = res$ind$coord[sample[!sample %in% rownames(res$ind.sup$coord)],]", file = file)
-             writeRmd("res$ind.sup$coord = res$ind.sup$coord[sample[sample %in% rownames(res$ind.sup$coord)],]", file = file)
+             writeRmd("res$ind.sup$coord = res$ind.sup$coord[sample[sample %in% rownames(res$ind.sup$coord)],,drop=FALSE]", file = file)
              dump("drawn", file = file, append = TRUE)
              dump("hab", file = file, append = TRUE)
              
@@ -211,7 +237,7 @@ test.de.Wilks <- function(x,grouping){
                
                #shuffle
                res$row$coord = res$row$coord[sample[!sample %in% rownames(res$row.sup$coord)],]
-               res$row.sup$coord = res$row.sup$coord[sample[sample %in% rownames(res$row.sup$coord)],] # works even if ind.sup = NULL
+               res$row.sup$coord = res$row.sup$coord[sample[sample %in% rownames(res$row.sup$coord)],,drop=FALSE] # works even if ind.sup = NULL
                
                plot.CA(res, axes = dim[1]:dim[2], choix = 'CA', invisible = c('var', 'quali'), selectRow = r.drawn, selectCol = c.drawn, habillage = hab, title = gettext("Overlayed factor map (CA)",domain="R-FactoInvestigate"), cex = cex)
              }
@@ -220,7 +246,7 @@ test.de.Wilks <- function(x,grouping){
              writeRmd("sample <- sample(rownames(res$call$Xtot), length(rownames(res$call$Xtot)))", file = file, start = TRUE, options = options)
              writeRmd("res$call$Xtot <- res$call$Xtot[sample,]", file = file)
              writeRmd("res$row$coord <- res$row$coord[sample[!sample %in% rownames(res$row.sup$coord)],]", file = file)
-             writeRmd("res$row.sup$coord <- res$row.sup$coord[sample[sample %in% rownames(res$row.sup$coord)],]", file = file)
+             writeRmd("res$row.sup$coord <- res$row.sup$coord[sample[sample %in% rownames(res$row.sup$coord)],,drop=FALSE]", file = file)
              dump("r.drawn", file = file, append = TRUE)
              dump("c.drawn", file = file, append = TRUE)
              dump("hab", file = file, append = TRUE)
@@ -321,7 +347,7 @@ test.de.Wilks <- function(x,grouping){
                
                #shuffle
                res$ind$coord = res$ind$coord[sample[!sample %in% rownames(res$ind.sup$coord)],]
-               res$ind.sup$coord = res$ind.sup$coord[sample[sample %in% rownames(res$ind.sup$coord)],] # works even if ind.sup = NULL
+               res$ind.sup$coord = res$ind.sup$coord[sample[sample %in% rownames(res$ind.sup$coord)],,drop=FALSE] # works even if ind.sup = NULL
                
                if(ellipse) {
                  plotellipses(res, axes = dim[1]:dim[2], invisible = c('var', 'quali'), select = drawn, keepvar = hab, title = gettext("Individuals factor map (MCA)",domain="R-FactoInvestigate"), cex = cex)
@@ -334,7 +360,7 @@ test.de.Wilks <- function(x,grouping){
              writeRmd("sample = sample(rownames(res$call$X), length(rownames(res$call$X)))", file = file, start = TRUE, options = options)
              writeRmd("res$call$X = res$call$X[sample,]", file = file)
              writeRmd("res$ind$coord = res$ind$coord[sample[!sample %in% rownames(res$ind.sup$coord)],]", file = file)
-             writeRmd("res$ind.sup$coord = res$ind.sup$coord[sample[sample %in% rownames(res$ind.sup$coord)],]", file = file)
+             writeRmd("res$ind.sup$coord = res$ind.sup$coord[sample[sample %in% rownames(res$ind.sup$coord)],,drop=FALSE]", file = file)
              dump("drawn", file = file, append = TRUE)
              dump("hab", file = file, append = TRUE)
              
